@@ -36,7 +36,7 @@ EXPECTED_DELIVERY = Literal['5min', '15min', 'Hourly', 'Daily', 'Weekly', 'Month
 # deploy_type 'File' for (FTP. Email, Upload)
 DEPLOY_TYPE = Literal['Email', 'Ftp', 'Upload', 'Timer']
 
-ACCOUNT = Literal['SwitchStorage', 'SwitchContainer', 'Argus', 'DataIngestion']
+ACCOUNT = Literal['SwitchStorage', 'SwitchContainer', 'Argus', 'DataIngestion', 'GatewayMqttStorage']
 
 DATA_INGESTION_CONTAINER = Literal['data-ingestion-adx', 'data-ingestion-timeseries-adx']
 
